@@ -4,6 +4,7 @@ from harpoon.errors import NoSuchKey, BadOption, NoSuchImage, BadCommand, BadIma
 from harpoon.formatter import MergedOptionStringFormatter
 from harpoon.helpers import a_temp_file, until
 from harpoon.processes import command_output
+from option_merge.helper import dot_joiner
 from harpoon.layers import Layers
 
 from docker.errors import APIError as DockerAPIError
@@ -713,7 +714,11 @@ class Image(object):
         """
         options = {"configuration": self.all_configuration, "path_prefix": None}
         options.update(kwargs)
-        return self.formatted("{0}.{1}".format(self.path, key), key, **options)
+        if isinstance(self.path, list):
+            path = self.path + [key]
+        else:
+            path = "{0}.{1}".format(self.path, key)
+        return self.formatted(path, key, **options)
 
     def formatted(self, *keys, **kwargs):
         """Get us a formatted value"""
@@ -728,6 +733,9 @@ class Image(object):
                 if key in configuration:
                     val = configuration[key]
                     break
+        else:
+            if keys:
+                key = dot_joiner(keys)
 
         if val is NotSpecified:
             if default is NotSpecified:
@@ -736,7 +744,13 @@ class Image(object):
                 return default
 
         if path_prefix:
-            path = "{0}.{1}".format(path_prefix, key)
+            if isinstance(path_prefix, list):
+                if key:
+                    path = path_prefix + [key]
+                else:
+                    path = [thing for thing in path_prefix]
+            else:
+                path = "{0}.{1}".format(path_prefix, key)
         else:
             path = key
 
@@ -895,12 +909,8 @@ class Imager(object):
     def images(self):
         """Make our image objects"""
         if not getattr(self, "_images", None):
-            if any('.' in key for key in self.configuration["images"].keys()):
-                illegal = [key for key in self.configuration["images"].keys() if '.' in key]
-                raise HarpoonError("Sorry, a limitation with option_merge means we can't have dots in key names", illegal=illegal)
-
             options = {"docker_context": self.docker_context, "interactive": self.interactive, "silent_build": self.silent_build}
-            images = dict((key, Image(key, self.configuration, "images.{0}".format(key), **options)) for key, val in self.configuration["images"].items())
+            images = dict((key, Image(key, self.configuration, ["images", key], **options)) for key, val in self.configuration["images"].items())
             for image in images.values():
                 image.setup_configuration()
             for image in images.values():
