@@ -93,7 +93,7 @@ class Harpoon(object):
             raise BadYaml("Expected yaml file to declare a dictionary", location=location, got=type(result))
 
         result["__mtime__"] = self.get_committime_or_mtime(location)
-        return result
+        return location, result
 
     def read_yaml(self, filepath):
         """Read in a yaml file"""
@@ -115,12 +115,15 @@ class Harpoon(object):
     def collect_configuration(self, configuration_file):
         """Return us a MergedOptions with this configuration and any collected configurations"""
         errors = []
-        collected = []
         result = self.read_yaml(configuration_file)
         result["__mtime__"] = self.get_committime_or_mtime(configuration_file)
 
-        configuration = MergedOptions.using(result)
+        configuration = MergedOptions.using(result, source=configuration_file)
         configuration_dir = os.path.dirname(os.path.abspath(configuration_file))
+
+        source, conf = self.home_dir_configuration()
+        configuration.update(conf, source=source)
+
         if "images.__images_from__" in configuration:
             images_from = MergedOptionStringFormatter(configuration, "images.__images_from__").format()
             del configuration["images.__images_from__"]
@@ -139,11 +142,11 @@ class Harpoon(object):
                             name = os.path.splitext(fle)[0]
                             result = self.read_yaml(location)
                             result["__mtime__"] = self.get_committime_or_mtime(location)
-                            collected.append({"images": {name: result}})
+                            configuration.update({"images": {name: result}}, source=location)
                         except BadYaml as error:
                             errors.append(error)
 
-        return MergedOptions.using(self.home_dir_configuration(), configuration, *collected)
+        return configuration
 
     ########################
     ###   TASKS
@@ -151,10 +154,12 @@ class Harpoon(object):
 
     def default_tasks(self):
         """Return default tasks"""
-        def t(action, description, **options):
-            return (action, Task(action, description=description, options=options, label="Harpoon"))
+        def t(name, description, action=None, **options):
+            if not action:
+                action = name
+            return (name, Task(action, description=description, options=options, label="Harpoon"))
         return dict([
-              t("ssh", "Run bash in one of the containers", command="/bin/bash")
+              t("ssh", "Run bash in one of the containers", command="/bin/bash", action="run")
             , t("run", "Run a command in one of the containers")
 
             , t("make", "Make one of the images")
@@ -197,8 +202,8 @@ class Harpoon(object):
 
         tasks = self.default_tasks()
         tasks.update(self.interpret_tasks(configuration, "tasks"))
-        for image in configuration["images"]:
-            nxt = self.interpret_tasks(configuration, "images.{0}.tasks".format(image))
+        for image in list(configuration["images"]):
+            nxt = self.interpret_tasks(configuration, ["images", image, "tasks"])
             for task in nxt.values():
                 task.add_option_defaults(image=image)
             tasks.update(nxt)
